@@ -10,11 +10,17 @@ Usage::
     client: CloudHSMClient = boto3.client("cloudhsm")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_cloudhsm.literals import (
+    ClientVersion,
+    ListHapgsPaginatorName,
+    ListHsmsPaginatorName,
+    ListLunaClientsPaginatorName,
+    SubscriptionType,
+)
 from mypy_boto3_cloudhsm.paginator import (
     ListHapgsPaginator,
     ListHsmsPaginator,
@@ -44,12 +50,6 @@ from mypy_boto3_cloudhsm.type_defs import (
     TagTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("CloudHSMClient",)
 
 
@@ -70,7 +70,7 @@ class Exceptions:
 
 class CloudHSMClient:
     """
-    [CloudHSM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client)
+    [CloudHSM.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client)
     """
 
     meta: ClientMeta
@@ -80,17 +80,17 @@ class CloudHSMClient:
         self, ResourceArn: str, TagList: List["TagTypeDef"]
     ) -> AddTagsToResourceResponseTypeDef:
         """
-        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
+        [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
         """
 
     def create_hapg(self, Label: str) -> CreateHapgResponseTypeDef:
         """
-        [Client.create_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
+        [Client.create_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
         """
 
     def create_hsm(
@@ -98,55 +98,55 @@ class CloudHSMClient:
         SubnetId: str,
         SshKey: str,
         IamRoleArn: str,
-        SubscriptionType: Literal["PRODUCTION"],
+        SubscriptionType: SubscriptionType,
         EniIp: str = None,
         ExternalId: str = None,
         ClientToken: str = None,
         SyslogIp: str = None,
     ) -> CreateHsmResponseTypeDef:
         """
-        [Client.create_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
+        [Client.create_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
         """
 
     def create_luna_client(
         self, Certificate: str, Label: str = None
     ) -> CreateLunaClientResponseTypeDef:
         """
-        [Client.create_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
+        [Client.create_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
         """
 
     def delete_hapg(self, HapgArn: str) -> DeleteHapgResponseTypeDef:
         """
-        [Client.delete_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
+        [Client.delete_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
         """
 
     def delete_hsm(self, HsmArn: str) -> DeleteHsmResponseTypeDef:
         """
-        [Client.delete_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
+        [Client.delete_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
         """
 
     def delete_luna_client(self, ClientArn: str) -> DeleteLunaClientResponseTypeDef:
         """
-        [Client.delete_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
+        [Client.delete_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
         """
 
     def describe_hapg(self, HapgArn: str) -> DescribeHapgResponseTypeDef:
         """
-        [Client.describe_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
+        [Client.describe_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
         """
 
     def describe_hsm(
         self, HsmArn: str = None, HsmSerialNumber: str = None
     ) -> DescribeHsmResponseTypeDef:
         """
-        [Client.describe_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
+        [Client.describe_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
         """
 
     def describe_luna_client(
         self, ClientArn: str = None, CertificateFingerprint: str = None
     ) -> DescribeLunaClientResponseTypeDef:
         """
-        [Client.describe_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
+        [Client.describe_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
         """
 
     def generate_presigned_url(
@@ -157,46 +157,46 @@ class CloudHSMClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
         """
 
     def get_config(
-        self, ClientArn: str, ClientVersion: Literal["5.1", "5.3"], HapgList: List[str]
+        self, ClientArn: str, ClientVersion: ClientVersion, HapgList: List[str]
     ) -> GetConfigResponseTypeDef:
         """
-        [Client.get_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
+        [Client.get_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
         """
 
     def list_available_zones(self) -> ListAvailableZonesResponseTypeDef:
         """
-        [Client.list_available_zones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
+        [Client.list_available_zones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
         """
 
     def list_hapgs(self, NextToken: str = None) -> ListHapgsResponseTypeDef:
         """
-        [Client.list_hapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
+        [Client.list_hapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
         """
 
     def list_hsms(self, NextToken: str = None) -> ListHsmsResponseTypeDef:
         """
-        [Client.list_hsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
+        [Client.list_hsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
         """
 
     def list_luna_clients(self, NextToken: str = None) -> ListLunaClientsResponseTypeDef:
         """
-        [Client.list_luna_clients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
+        [Client.list_luna_clients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
         """
 
     def modify_hapg(
         self, HapgArn: str, Label: str = None, PartitionSerialList: List[str] = None
     ) -> ModifyHapgResponseTypeDef:
         """
-        [Client.modify_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
+        [Client.modify_hapg documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
         """
 
     def modify_hsm(
@@ -209,39 +209,39 @@ class CloudHSMClient:
         SyslogIp: str = None,
     ) -> ModifyHsmResponseTypeDef:
         """
-        [Client.modify_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
+        [Client.modify_hsm documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
         """
 
     def modify_luna_client(
         self, ClientArn: str, Certificate: str
     ) -> ModifyLunaClientResponseTypeDef:
         """
-        [Client.modify_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
+        [Client.modify_luna_client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
         """
 
     def remove_tags_from_resource(
         self, ResourceArn: str, TagKeyList: List[str]
     ) -> RemoveTagsFromResourceResponseTypeDef:
         """
-        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
+        [Client.remove_tags_from_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_hapgs"]) -> ListHapgsPaginator:
+    def get_paginator(self, operation_name: ListHapgsPaginatorName) -> ListHapgsPaginator:
         """
-        [Paginator.ListHapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+        [Paginator.ListHapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["list_hsms"]) -> ListHsmsPaginator:
+    def get_paginator(self, operation_name: ListHsmsPaginatorName) -> ListHsmsPaginator:
         """
-        [Paginator.ListHsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+        [Paginator.ListHsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["list_luna_clients"]
+        self, operation_name: ListLunaClientsPaginatorName
     ) -> ListLunaClientsPaginator:
         """
-        [Paginator.ListLunaClients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+        [Paginator.ListLunaClients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
         """
