@@ -12,10 +12,8 @@ Usage::
 import sys
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_cloudhsm.literals import CloudHsmObjectState, HsmStatus, SubscriptionType
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -76,7 +74,7 @@ DescribeHapgResponseTypeDef = TypedDict(
         "Label": str,
         "LastModifiedTimestamp": str,
         "PartitionSerialList": List[str],
-        "State": Literal["READY", "UPDATING", "DEGRADED"],
+        "State": CloudHsmObjectState,
     },
     total=False,
 )
@@ -85,14 +83,12 @@ DescribeHsmResponseTypeDef = TypedDict(
     "DescribeHsmResponseTypeDef",
     {
         "HsmArn": str,
-        "Status": Literal[
-            "PENDING", "RUNNING", "UPDATING", "SUSPENDED", "TERMINATING", "TERMINATED", "DEGRADED"
-        ],
+        "Status": HsmStatus,
         "StatusDetails": str,
         "AvailabilityZone": str,
         "EniId": str,
         "EniIp": str,
-        "SubscriptionType": Literal["PRODUCTION"],
+        "SubscriptionType": SubscriptionType,
         "SubscriptionStartDate": str,
         "SubscriptionEndDate": str,
         "VpcId": str,
